@@ -4,7 +4,14 @@ from git import *
 from django.conf import settings
 
 def get_repos():
-    return [Repo(os.path.join(settings.REPOS_ROOT, dir)) for dir in os.listdir(settings.REPOS_ROOT) if os.path.isdir(os.path.join(settings.REPOS_ROOT, dir))]
+    repos = []
+    for dir in os.listdir(settings.REPOS_ROOT):
+        if os.path.isdir(os.path.join(settings.REPOS_ROOT, dir)):
+            try:
+                repos.append(Repo(os.path.join(settings.REPOS_ROOT, dir)))
+            except Exception:
+                continue
+    return repos
 
 def get_repo(name):
     return Repo(os.path.join(settings.REPOS_ROOT, name))
